==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditActionsTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditActionsTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditActionsTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
        a.aa("WebGridRowEditActionsTemplateContext", function () { return new WebGridRowEditActionsTemplateContextDescription(); });
        a.z("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditActionsTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditActionsTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditActionsTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditActionsTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
        a.ac("WebGridRowEditActionsTemplateContext", function () { return new WebGridRowEditActionsTemplateContextDescription(); });
        a.ab("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditActionsTemplateContextDescriptionMetadata };
